@@ -1,26 +1,25 @@
-"""
-tspaser.py
-----------
-
-Parse the concrete syntax tree output by tree-sitter into an abstract syntax tree.
-
-"""
-import tree_sitter
-from rsm import nodes, translator, transformer
-from itertools import groupby
-from icecream import ic
-from typing import cast, Callable
-import string
+"""Input: RSM source string -- Output: abstract syntax tree."""
+import logging
 import re
+import string
+import sys
+from itertools import groupby
+from typing import Callable, Optional, cast
+
+import tree_sitter
+from icecream import ic
+from tree_sitter import Node as TSNode
+from tree_sitter import Tree as TSTree
+
+from rsm import nodes, transformer, translator
 
 from .util import EscapedString
-import logging
 
 logger = logging.getLogger("RSM").getChild("parse")
 
 
 class RSMParserError(Exception):
-    def __init__(self, pos: int | None = None, msg: str | None = None) -> None:
+    def __init__(self, pos: Optional[int] = None, msg: Optional[str] = None) -> None:
         self.pos = pos
         self.msg = f"Parser error at position {self.pos}" if msg is None else msg
         super().__init__(self.msg)
@@ -52,6 +51,8 @@ PUSH_THESE_TYPES = {
 
 
 class TSParser:
+    """Parse the concrete syntax tree output by tree-sitter into an abstract syntax tree."""
+
     def __init__(self):
         # Execute these two lines only if we need to compile the parser on the fly.
         # Otherwise, just use the next line.
@@ -72,8 +73,16 @@ class TSParser:
         # This needs to happen BEFORE we run this file.  Trying to set this env variable
         # from this interpreter session will not work.
         #
-        self._lang = tree_sitter.Language("rsm.so", "rsm")
+        if sys.platform == "win32":
+            import os
+            from pathlib import Path
 
+            path = Path.home() / ".tree-sitter" / "bin"
+            os.add_dll_directory(str(path))
+            library_fn = "rsm.dll"
+        else:
+            library_fn = "rsm.so"
+        self._lang = tree_sitter.Language(library_fn, "rsm")
         self._parser = tree_sitter.Parser()
         self._parser.set_language(self._lang)
         self.cst = None
@@ -83,9 +92,8 @@ class TSParser:
         logger.info("Parsing...")
         self.cst = self._parser.parse(bytes(str(src), "utf-8"))
 
-        traverse(self.cst)
-        # if logger.getEffectiveLevel() <= logging.DEBUG:
-        #     traverse(self.cst)
+        if logger.getEffectiveLevel() <= logging.DEBUG:
+            traverse(self.cst)
 
         if not abstractify:
             return self.cst
@@ -99,7 +107,7 @@ class TSParser:
         return self.ast
 
 
-def traverse(tree, named_only=True):
+def traverse(tree: TSTree, named_only: bool = True):
     # allow traverse() to print to stdout rather than use logger because it will
     # look better this way
 
@@ -178,7 +186,7 @@ CST_TYPE_TO_AST_TYPE: dict[str, Callable] = {
 }
 
 
-def parse_metakey_list(cst_key, cst_val):
+def parse_metakey_list(cst_key: TSNode, cst_val: TSNode):
     key = cst_key.named_children[0].type
     if cst_val.named_children:
         val = [c.text.decode("utf-8").strip() for c in cst_val.named_children]
@@ -187,17 +195,17 @@ def parse_metakey_list(cst_key, cst_val):
     return key, val
 
 
-def parse_metakey_text(cst_key, cst_val):
+def parse_metakey_text(cst_key: TSNode, cst_val: TSNode):
     key = cst_key.named_children[0].type
     val = cst_val.text.decode("utf-8").strip()
     return key, val
 
 
-def parse_metakey_any(cst_key, cst_val):
+def parse_metakey_any(cst_key: TSNode, cst_val: TSNode):
     return parse_metakey_text(cst_key, cst_val)
 
 
-def parse_metakey_bool(cst_key, _):
+def parse_metakey_bool(cst_key: TSNode, _):
     key = cst_key.named_children[0].type
     return key, True
 
@@ -219,12 +227,12 @@ def normalize_text(root):
         # Merge consecutive text nodes (each text node ends at a newline, so consecutive
         # text nodes are just adjacent lines of text and can always be merged).  Also,
         # pad all text with spaces.  Spurious spaces added here are removed later.
-        for run_is_text, run in groupby(
+        for run_is_text, run_generator in groupby(
             node.children, key=lambda c: isinstance(c, nodes.Text)
         ):
             if not run_is_text:
                 continue
-            run = list(run)
+            run = list(run_generator)
 
             if len(run) == 2:
                 first, last = run
@@ -252,13 +260,9 @@ def normalize_text(root):
 
         # Strip both ends of a paragraph's text content.
         if isinstance(node, nodes.Paragraph):
-            if (first := node.first_of_type(nodes.Text)) and not first.prev_sibling(
-                object
-            ):
+            if (first := node.first_of_type(nodes.Text)) and not first.prev_sibling():
                 first.text = first.text.lstrip()
-            if (last := node.last_of_type(nodes.Text)) and not last.next_sibling(
-                object
-            ):
+            if (last := node.last_of_type(nodes.Text)) and not last.next_sibling():
                 last.text = last.text.rstrip()
 
         # At this point, the whitespace within non-paragraphs (e.g. Span, Claim) has
@@ -320,15 +324,15 @@ def make_ast(cst):
 
             continue
         if cst_node.type == "bibitem":
-            ast_node = nodes.Bibitem()
-            ast_node.kind = cst_node.child_by_field_name("kind").text.decode("utf-8")
-            ast_node.label = cst_node.child_by_field_name("label").text.decode("utf-8")
+            bib_node = nodes.Bibitem()
+            bib_node.kind = cst_node.child_by_field_name("kind").text.decode("utf-8")
+            bib_node.label = cst_node.child_by_field_name("label").text.decode("utf-8")
             for pair in [c for c in cst_node.named_children if c.type == "bibitempair"]:
                 key, value = pair.named_children
                 key, value = key.text.decode("utf-8"), value.text.decode("utf-8")
-                setattr(ast_node, key, value)
+                setattr(bib_node, key, value)
 
-            parent.append(ast_node)
+            parent.append(bib_node)
             continue
 
         # After this if statement, cst_node is the node that actually contains the
